@@ -4,13 +4,13 @@ pub fn list(config: &config::structs::Config) {
 	for (i, profile) in config.profiles.iter().enumerate() {
 		println!(
 			"{}{}
-		\r  Output directory:   {:?}
+		\r  Output directory:   {}
 		\r  Minecraft Version:  {}
 		\r  Mod Loader:         {}
 		\r  Mods:               {}\n",
-			if i == config.active_profile { "* " } else { "" },
 			profile.name,
-			profile.output_dir,
+			if i == config.active_profile { " *" } else { "" },
+			profile.output_dir.display(),
 			profile.game_version,
 			profile.mod_loader,
 			profile.mods.len(),
